# My Data Toolkit: DToolKit

[![PyPI Project Version](https://img.shields.io/pypi/v/my-data-toolkit.svg)](https://pypi.org/project/my-data-toolkit/)
[![PyPI Python Versions](https://img.shields.io/pypi/pyversions/my-data-toolkit)](https://pypi.org/project/my-data-toolkit/)
[![Tests Status](https://github.com/Zeroto521/my-data-toolkit/actions/workflows/tests.yml/badge.svg)](https://github.com/Zeroto521/my-data-toolkit/actions/workflows/tests.yml)
[![Nightly Tests Status](https://github.com/Zeroto521/my-data-toolkit/actions/workflows/nightly-tests.yml/badge.svg)](https://github.com/Zeroto521/my-data-toolkit/actions/workflows/nightly-tests.yml)
[![CodeQL Status](https://github.com/Zeroto521/my-data-toolkit/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/Zeroto521/my-data-toolkit/actions/workflows/codeql-analysis.yml)
[![Coverage Status](https://codecov.io/gh/Zeroto521/my-data-toolkit/branch/master/graph/badge.svg)](https://codecov.io/gh/Zeroto521/my-data-toolkit)
[![Documentation Status](https://readthedocs.org/projects/my-data-toolkit/badge/?version=latest)](https://my-data-toolkit.readthedocs.io/en/latest/?badge=latest)

Face the engineering of data preprocessing.

See [documentation](https://my-data-toolkit.readthedocs.io/) for more information.

## Dependencies

DToolKit depends on the following packages:

- Requirements
  - Python (>= 3.7)
  - Pandas (>= 1.3.4)
- Optionals
  - Scikit-learn (>= 1.0)
  - GeoPandas (>= 0.9.0)
  - PyGEOS (>= 0.11.1)

See the [installation docs](https://my-data-toolkit.readthedocs.io/en/latest/guide/installation.html) for all details.
